===============
Qbiome
===============

.. figure:: https://img.shields.io/pypi/dm/qbiome.svg
   :alt: qbiome PyPI Downloads
.. figure:: https://img.shields.io/pypi/v/qbiome.svg
   :alt: qbiome curent version

.. image:: http://zed.uchicago.edu/logo/qbiome.png
   :height: 300px
   :scale: 30 %
   :alt: qbiome logo
   :align: center

.. class:: no-web no-pdf

:Info: Draft link will be posted here
:Author: ZeD@UChicago <zed.uchicago.edu>
:Description: Application of quasinets (https://pypi.org/project/quasinet/) for microbiome analysis  for learning rules of organization, maturation, competition and succession in microbiome ecosystems. 
:Documentation: https://zeroknowledgediscovery.github.io/qbiome/qbiome/index.html


**Usage:**

.. code-block::

    import qbiome
    from qbiome.data_formatter import DataFormatter
    from qbiome.quantizer import Quantizer
    from qbiome.qnet_orchestrator import QnetOrchestrator
    from qbiome.forecaster import Forecaster


.. image:: https://github.com/zeroknowledgediscovery/qbiome/raw/main/images/img2.png
   :scale: 50 %
   :alt: alternate text
   :align: center 
